@@ -22,7 +22,7 @@ our @EXPORT = qw(
 our @ISA = qw(Exporter);
 
 # Set the package version. 
-our $VERSION = '0.24';
+our $VERSION = '0.25';
 
 # Load the Perl modules.
 use POSIX qw(ttyname);
@@ -586,16 +586,29 @@ sub get_terminal_ftn {
     return $terminal_ftn; 
 };
 
+# ============================================================================ #
+# Subroutine check_os                                                          # 
+# ============================================================================ #
+sub check_os{ 
+    # Check the operating system.
+    if ($^O eq "MSWin32") {
+        print "This module works not on Windows. Bye.\n";
+        exit 1;
+    };
+};
+
 # ============================================================================ #
 # Subroutine whichterminalami                                                  # 
 #                                                                              #
 # Description:                                                                 #
-# Identify the terminal name.                                                  #
+# Identify the terminal emulator.                                              #
 #                                                                              #
-# @argument: $_[0] => $flag  Output format flag  (array)                       # 
+# @argument: $_[0] => $flag  Output format flag  (scalar)                      # 
 # @return:   $terminal       Terminal name       (scalar)                      #
 # ============================================================================ #
 sub whichterminalami {
+    # Check the operating system.
+    check_os();
     # Initialise the output format flag variable.
     my $flag = "";
     # Set the output format flag.
